@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 
 
 from logging import getLogger
@@ -192,11 +192,10 @@ class Mocker(Targetting):
         return _configurators[key]
 
 
-class Verifier(object):
+class Verifier(Targetting):
 
     def __init__(self, target):
-        self._target_name = target.__name__
-        self._target = target
+        Targetting.__init__(self, target)
         self._attribute_name = None
 
     def __getattr__(self, name):
